@@ -1,14 +1,13 @@
 import time
 
 
-class Playlist(object):
+class Playlist:
 
     """ Representation of a playist, has list of songs. """
 
     def __init__(self, name=None, songs=None):
         """ class members. """
         self.name = name
-        self.creation = time.time()
         self.songs = songs or []
 
     def __len__(self):
@@ -18,6 +17,9 @@ class Playlist(object):
     def __getitem__(self, sliced):
         return self.songs[sliced]
 
+    def __setitem__(self, position, item):
+        self.songs[position] = item
+
     def __iter__(self):
         for i in self.songs:
             yield i
@@ -30,10 +32,10 @@ class Playlist(object):
         return duration
 
 
-class Video(object):
+class Video:
 
     """ Class to represent a YouTube video. """
-
+    description = ""
     def __init__(self, ytid, title, length):
         """ class members. """
         self.ytid = ytid
